function list = cullsegments(list, seconds);

%CULLSEGMENTS remove short or zero length segments
%
% CULLSEGMENTS removes segments from the given segment list which are
% shorter than or equal to the specified duration in seconds.  The
% resulting list is returned.
%
%SYNOPSIS
%   OUT = cullsegments(IN, SECONDS);
%
%INPUTS
%   IN        input segment list
%   SECONDS   (OPTIONAL) minimum segment length in seconds
%       If the minimum segment length is not specified, CULLSEGMENTS removes
%       zero length segments.
%
%OUTPUT
%   OUT       output segment list
%
% The segments list should be provided in the form of an N-by-2 matrix,
% formed from adjacent column-wise vectors of segment start and stop
% times.
%
%   start1 stop1
%   start2 stop2
%   start3 stop3
%    ...    ...
%   startN stopN
%
% By definition, a segment is the half closed interval [start,stop).
% A segment is inclusive of the specified start time, but exclusive of
% the specified stop time.  The duration of a segment is defined as the
% difference between stop and start times.
%
% As an alternative, each segment may also be specified by its start time
% and duration.  However, the resulting segment list will be returned in
% terms of start and stop times.
%
% See also PADSEGMENTS and ALIGNSEGMENTS.
%
%AUTHOR
%   Shourov K. Chatterji (No longer part of the LV Collaboration)

% $Id: cullsegments.m 6645 2010-12-09 16:09:14Z diego.menendez@LIGO.ORG $

% parse command line arguments
error(nargchk(1, 2, nargin));

% default minimum segment length
if nargin == 1,
  seconds = 0;
end

% standardize segment list
list = stdsegments(list);

% handle empty lists
if isempty(list),
  return;
end

% extract start and stop vectors
start = list(:,1);
stop = list(:,2);

% find segment duration
duration = stop - start;

% indices of segments to keep
indices = (duration > seconds);

% remove short segments
start = start(indices);
stop = stop(indices);

% create return segment list
list = [start stop];

% standardize segment list
list = stdsegments(list);

% return to calling function
return;
