function result = orsegments(varargin);

%ORSEGMENTS Determine union of segment lists
%
% ORSEGMENTS returns the segment list corresponding to the union of
% the individual segment lists provided as arguments.  ORSEGMENTS
% allows an arbitrary number of input segment lists.
%
%SYNOPSIS
%   LIST = orsegments(LIST1, LIST2, ...);
%
%INPUT
%   LIST1, LIST2, ... - segments lists in the form of N-by-2 matrices,
% formed from adjacent column-wise vectors of segment start and stop
% times.
%
%   start1 stop1
%   start2 stop2
%   start3 stop3
%    ...    ...
%   startN stopN
%
% By definition, a segment is the half closed interval [start,stop).
% A segment is inclusive of the specified start time, but exclusive of
% the specified stop time.  The duration of a segment is defined as the
% difference between stop and start times.
%
% As an alternative, each segment may also be specified by its start time
% and duration.  However, the resulting segment list will be returned in
% terms of start and stop times.
%
%OUTPUT
%   LIST - OR combination of input lists
%
% ORSEGMENTS also uses CULLSEGMENTS and MERGESEGMENTS to remove zero
% length segments and merge any overlapping or adjacent segments.
%
% See also ANDSEGMENTS, NANDSEGMENTS, and NORSEGMENTS.
%
%AUTHOR
% Shourov K. Chatterji (No longer part of the LC Collaboration)

% $Id: orsegments.m 6645 2010-12-09 16:09:14Z diego.menendez@LIGO.ORG $

% number of segment lists
lists = nargin;

% standardize segment lists
for list = 1 : lists,
  varargin{list} = stdsegments(varargin{list});
end

% remove zero length segments from lists
for list = 1 : lists,
  varargin{list} = cullsegments(varargin{list});
end

% merge overlapping segments within each list
for list = 1 : lists,
  varargin{list} = mergesegments(varargin{list});
end

% handle empty lists
notempty = [];
for list = 1 : lists,
  if ~isempty(varargin{list}),
    notempty = [notempty list];
  end
end
lists = length(notempty);
if lists == 0,
  result = [];
  return;
end
[tmp{1:lists}] = deal(varargin{notempty});
varargin = tmp;

% extract start and stop vectors
start = cell(1, lists);
stop = cell(1, lists);
for list = 1 : lists,
  start{list} = varargin{list}(:,1);
  stop{list} = varargin{list}(:,2);
end

% combine segment lists
times = [];
edges = [];
for list = 1 : lists,
  times = [times; start{list};];
  edges = [edges; ones(size(start{list}));];
end
for list = 1 : lists,
  times = [times; stop{list};];
  edges = [edges; -ones(size(start{list}));];
end

% find combined segment boundaries
[times, indices] = sort(times);
edges = edges(indices);
edges = cumsum(edges);

% check for overlapping segments
if (max(edges) > lists) | (min(edges) < 0),
  error('one or more segment lists contain overlapping segments');
end

% find OR segments
indices = find(edges == 0);
START = [times(1); times(indices(1:end-1) + 1);];
STOP = times(indices);

% create resulting segment list
result = [START STOP];

% remove zero length sequences
result = cullsegments(result);

% merge overlapping or adjacent segments
result = mergesegments(result);

% standardize segment list
result = stdsegments(result);

% return to calling function
return;
